"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mapStateToProps = exports.mapDispatchToProps = exports.default = exports.ProblemEditor = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactRedux = require("react-redux");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _paragon = require("@openedx/paragon");
var _i18n = require("@edx/frontend-platform/i18n");
var _SelectTypeModal = _interopRequireDefault(require("./components/SelectTypeModal"));
var _EditProblemView = _interopRequireDefault(require("./components/EditProblemView"));
var _redux = require("../../data/redux");
var _requests = require("../../data/constants/requests");
var _messages = _interopRequireDefault(require("./messages"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
const ProblemEditor = _ref => {
  let {
    onClose,
    returnFunction,
    // Redux
    problemType,
    blockFinished,
    blockFailed,
    blockValue,
    initializeProblemEditor,
    advancedSettingsFinished
  } = _ref;
  _react.default.useEffect(() => {
    if (blockFinished && !blockFailed) {
      initializeProblemEditor(blockValue);
    }
  }, [blockFinished, blockFailed]);
  if (!blockFinished || !advancedSettingsFinished) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      className: "text-center p-6",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Spinner, {
        animation: "border",
        className: "m-3",
        screenreadertext: "Loading Problem Editor"
      })
    });
  }
  if (blockFailed) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      className: "text-center p-6",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_i18n.FormattedMessage, _objectSpread({}, _messages.default.blockFailed))
    });
  }
  if (problemType === null) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectTypeModal.default, {
      onClose
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_EditProblemView.default, {
    onClose,
    returnFunction
  });
};
exports.ProblemEditor = ProblemEditor;
ProblemEditor.defaultProps = {
  returnFunction: null
};
ProblemEditor.propTypes = {
  onClose: _propTypes.default.func.isRequired,
  returnFunction: _propTypes.default.func,
  // redux
  advancedSettingsFinished: _propTypes.default.bool.isRequired,
  blockFinished: _propTypes.default.bool.isRequired,
  blockFailed: _propTypes.default.bool.isRequired,
  problemType: _propTypes.default.string.isRequired,
  initializeProblemEditor: _propTypes.default.func.isRequired,
  blockValue: _propTypes.default.objectOf(_propTypes.default.shape({})).isRequired
};
const mapStateToProps = state => ({
  blockFinished: _redux.selectors.requests.isFinished(state, {
    requestKey: _requests.RequestKeys.fetchBlock
  }),
  blockFailed: _redux.selectors.requests.isFailed(state, {
    requestKey: _requests.RequestKeys.fetchBlock
  }),
  problemType: _redux.selectors.problem.problemType(state),
  blockValue: _redux.selectors.app.blockValue(state),
  advancedSettingsFinished: _redux.selectors.requests.isFinished(state, {
    requestKey: _requests.RequestKeys.fetchAdvancedSettings
  })
});
exports.mapStateToProps = mapStateToProps;
const mapDispatchToProps = exports.mapDispatchToProps = {
  initializeProblemEditor: _redux.thunkActions.problem.initializeProblem
};
var _default = exports.default = (0, _i18n.injectIntl)((0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(ProblemEditor));
//# sourceMappingURL=index.js.map